<?php

namespace Litecms\StairStepsSettings\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\StairStepsSettings\Http\Requests\StairStepsSettingsRequest;
use Litecms\StairStepsSettings\Interfaces\StairStepsSettingsRepositoryInterface;
use Litecms\StairStepsSettings\Models\StairStepsSettings;

/**
 * Resource controller class for stair_steps_settings.
 */
class StairStepsSettingsResourceController extends BaseController
{

    /**
     * Initialize stair_steps_settings resource controller.
     *
     * @param type StairStepsSettingsRepositoryInterface $stair_steps_settings
     *
     * @return null
     */
    public function __construct(StairStepsSettingsRepositoryInterface $stair_steps_settings)
    {
        parent::__construct();
        $this->repository = $stair_steps_settings;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\StairStepsSettings\Repositories\Criteria\StairStepsSettingsResourceCriteria::class);
    }

    /**
     * Display a list of stair_steps_settings.
     *
     * @return Response
     */
    public function index(StairStepsSettingsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\StairStepsSettings\Repositories\Presenter\StairStepsSettingsPresenter::class)
                ->$function();
        }

        $stair_steps_settings = $this->repository->paginate();

        return $this->response->title(trans('stair_steps_settings::stair_steps_settings.names'))
            ->view('stair_steps_settings::stair_steps_settings.index', true)
            ->data(compact('stair_steps_settings'))
            ->output();
    }

    /**
     * Display stair_steps_settings.
     *
     * @param Request $request
     * @param Model   $stair_steps_settings
     *
     * @return Response
     */
    public function show(StairStepsSettingsRequest $request, StairStepsSettings $stair_steps_settings)
    {

        if ($stair_steps_settings->exists) {
            $view = 'stair_steps_settings::stair_steps_settings.show';
        } else {
            $view = 'stair_steps_settings::stair_steps_settings.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('stair_steps_settings::stair_steps_settings.name'))
            ->data(compact('stair_steps_settings'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new stair_steps_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(StairStepsSettingsRequest $request)
    {

        $stair_steps_settings = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('stair_steps_settings::stair_steps_settings.name')) 
            ->view('stair_steps_settings::stair_steps_settings.create', true) 
            ->data(compact('stair_steps_settings'))
            ->output();
    }

    /**
     * Create new stair_steps_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(StairStepsSettingsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $stair_steps_settings                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('stair_steps_settings::stair_steps_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('stair_steps_settings/stair_steps_settings/' . $stair_steps_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/stair_steps_settings/stair_steps_settings'))
                ->redirect();
        }

    }

    /**
     * Show stair_steps_settings for editing.
     *
     * @param Request $request
     * @param Model   $stair_steps_settings
     *
     * @return Response
     */
    public function edit(StairStepsSettingsRequest $request, StairStepsSettings $stair_steps_settings)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('stair_steps_settings::stair_steps_settings.name'))
            ->view('stair_steps_settings::stair_steps_settings.edit', true)
            ->data(compact('stair_steps_settings'))
            ->output();
    }

    /**
     * Update the stair_steps_settings.
     *
     * @param Request $request
     * @param Model   $stair_steps_settings
     *
     * @return Response
     */
    public function update(StairStepsSettingsRequest $request, StairStepsSettings $stair_steps_settings)
    {
        try {
            $attributes = $request->all();

            $stair_steps_settings->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('stair_steps_settings::stair_steps_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('stair_steps_settings/stair_steps_settings/' . $stair_steps_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('stair_steps_settings/stair_steps_settings/' . $stair_steps_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the stair_steps_settings.
     *
     * @param Model   $stair_steps_settings
     *
     * @return Response
     */
    public function destroy(StairStepsSettingsRequest $request, StairStepsSettings $stair_steps_settings)
    {
        try {

            $stair_steps_settings->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('stair_steps_settings::stair_steps_settings.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('stair_steps_settings/stair_steps_settings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('stair_steps_settings/stair_steps_settings/' . $stair_steps_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple stair_steps_settings.
     *
     * @param Model   $stair_steps_settings
     *
     * @return Response
     */
    public function delete(StairStepsSettingsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('stair_steps_settings::stair_steps_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('stair_steps_settings/stair_steps_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/stair_steps_settings/stair_steps_settings'))
                ->redirect();
        }

    }

    /**
     * Restore deleted stair_steps_settings.
     *
     * @param Model   $stair_steps_settings
     *
     * @return Response
     */
    public function restore(StairStepsSettingsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('stair_steps_settings::stair_steps_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/stair_steps_settings/stair_steps_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/stair_steps_settings/stair_steps_settings/'))
                ->redirect();
        }

    }

}
