<?php

namespace Litecms\StairStepsSettings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\StairStepsSettings\Models\StairStepsSettings;

class StairStepsSettingsPolicy
{

    /**
     * Determine if the given user can view the stair_steps_settings.
     *
     * @param UserPolicy $user
     * @param StairStepsSettings $stair_steps_settings
     *
     * @return bool
     */
    public function view(UserPolicy $user, StairStepsSettings $stair_steps_settings)
    {
        if ($user->canDo('stair_steps_settings.stair_steps_settings.view') && $user->isAdmin()) {
            return true;
        }

        return $stair_steps_settings->user_id == user_id() && $stair_steps_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a stair_steps_settings.
     *
     * @param UserPolicy $user
     * @param StairStepsSettings $stair_steps_settings
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('stair_steps_settings.stair_steps_settings.create');
    }

    /**
     * Determine if the given user can update the given stair_steps_settings.
     *
     * @param UserPolicy $user
     * @param StairStepsSettings $stair_steps_settings
     *
     * @return bool
     */
    public function update(UserPolicy $user, StairStepsSettings $stair_steps_settings)
    {
        if ($user->canDo('stair_steps_settings.stair_steps_settings.edit') && $user->isAdmin()) {
            return true;
        }

        return $stair_steps_settings->user_id == user_id() && $stair_steps_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given stair_steps_settings.
     *
     * @param UserPolicy $user
     * @param StairStepsSettings $stair_steps_settings
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, StairStepsSettings $stair_steps_settings)
    {
        return $stair_steps_settings->user_id == user_id() && $stair_steps_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given stair_steps_settings.
     *
     * @param UserPolicy $user
     * @param StairStepsSettings $stair_steps_settings
     *
     * @return bool
     */
    public function verify(UserPolicy $user, StairStepsSettings $stair_steps_settings)
    {
        if ($user->canDo('stair_steps_settings.stair_steps_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given stair_steps_settings.
     *
     * @param UserPolicy $user
     * @param StairStepsSettings $stair_steps_settings
     *
     * @return bool
     */
    public function approve(UserPolicy $user, StairStepsSettings $stair_steps_settings)
    {
        if ($user->canDo('stair_steps_settings.stair_steps_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
